==> angular_analyzer_plugin-0.0.10.tar.gz: lib/src/from_file_prefixed_error.dart <==
import 'package:analyzer/error/error.dart';
import 'package:analyzer/src/generated/source.dart';

// A wrapper around AnalysisError which also links back to a "from" file for
// context.
//
// Is a wrapper, not just an extension, so that it can have a different hashCode
// than the error without a "from" path, in the case that a file is included
// both sanely and strangely (which is common: prod and test).
class FromFilePrefixedError implements AnalysisError {
  final String fromSourcePath;
  final String originalMessage;
  final AnalysisError originalError;
  String _message;

  FromFilePrefixedError(Source fromSource, AnalysisError originalError)
      : originalMessage = originalError.message,
        fromSourcePath = fromSource.fullName,
        originalError = originalError {
    _message = "$originalMessage (from $fromSourcePath)";
  }

  FromFilePrefixedError.fromPath(
      this.fromSourcePath, AnalysisError originalError)
      : originalMessage = originalError.message,
        originalError = originalError {
    _message = "$originalMessage (from $fromSourcePath)";
  }

  @override
  ErrorCode get errorCode => originalError.errorCode;

  @override
  int get offset => originalError.offset;

  @override
  set offset(int v) => originalError.offset = v;

  @override
  int get length => originalError.length;

  @override
  set length(int v) => originalError.length = v;

  @override
  bool get isStaticOnly => originalError.isStaticOnly;

  @override
  set isStaticOnly(bool v) => originalError.isStaticOnly = v;

  @override
  String get correction => originalError.correction;

  @override
  Source get source => originalError.source;

  @override
  String get message => _message;

  @override
  int get hashCode {
    var hashCode = offset;
    hashCode ^= (_message != null) ? _message.hashCode : 0;
    hashCode ^= (source != null) ? source.hashCode : 0;
    return hashCode;
  }
}

==> angular_analyzer_plugin-0.0.14.tar.gz: lib/src/from_file_prefixed_error.dart <==
import 'package:analyzer/error/error.dart';
import 'package:analyzer/src/generated/source.dart';

// A wrapper around AnalysisError which also links back to a "from" file and
// classname for context.
//
// Is a wrapper, not just an extension, so that it can have a different hashCode
// than the error without a "from" path, in the case that a file is included
// both sanely and strangely (which is common: prod and test).
class FromFilePrefixedError implements AnalysisError {
  final String fromSourcePath;
  final String classname;
  final String originalMessage;
  final AnalysisError originalError;
  String _message;

  FromFilePrefixedError(
      Source fromSource, String classname, AnalysisError originalError)
      : this.fromPath(fromSource.fullName, classname, originalError);

  FromFilePrefixedError.fromPath(
      this.fromSourcePath, this.classname, AnalysisError originalError)
      : originalMessage = originalError.message,
        originalError = originalError,
        assert(classname != null),
        assert(classname.isNotEmpty),
        assert(fromSourcePath != null),
        assert(fromSourcePath.isNotEmpty) {
    _message = "In $classname: $originalMessage (from $fromSourcePath)";
  }

  @override
  ErrorCode get errorCode => originalError.errorCode;

  @override
  int get offset => originalError.offset;

  @override
  set offset(int v) => originalError.offset = v;

  @override
  int get length => originalError.length;

  @override
  set length(int v) => originalError.length = v;

  @override
  bool get isStaticOnly => originalError.isStaticOnly;

  @override
  set isStaticOnly(bool v) => originalError.isStaticOnly = v;

  @override
  String get correction => originalError.correction;

  @override
  Source get source => originalError.source;

  @override
  String get message => _message;

  @override
  int get hashCode {
    var hashCode = offset;
    hashCode ^= (_message != null) ? _message.hashCode : 0;
    hashCode ^= (source != null) ? source.hashCode : 0;
    return hashCode;
  }
}
